@@ -5,11 +5,10 @@ import datetime
 from collections import namedtuple
 import re
 from datetime import date, datetime
+import logging
 BlogPost = namedtuple('BlogPost', 'postId url title videoId content labels amara_embed last_updated')
 
 
-
-
 class BlogClient:
 
     def __init__(self, client_json_file):
@@ -40,7 +39,7 @@ class BlogClient:
         if videoId and obind1 >= 0 and obind2 >=0 :
             newcontent = content[0:obind1]+'<iframe src="https://www.youtube.com/embed/'+videoId+'" width="640" height="390" frameborder="0" allowfullscreen></iframe>'+content[obind2+7:len(content)]
             posts_doc['content'] = newcontent
-            request = self.posts.update(blogId=blogId, postId=postId, body=posts_doc, last_updated=datetime.utcnow())
+            request = self.posts.update(blogId=blogId, postId=postId, body=posts_doc)
             print('Replacing object' + postId)
             request.execute()
 
@@ -60,6 +59,15 @@ class BlogClient:
         result_dict = {'content':content, 'videoId': videoId, 'posts_doc': posts_doc}
         return result_dict
 
+    def invalidate_post(self, blogId, postId):
+        logging.info(f'Invalidating post {blogId}, {postId}')
+        _ = self.extract_content_and_video(blogId, postId)
+        content, videoId, posts_doc = _["content"], _["videoId"], _["posts_doc"]
+        posts_doc['content'] = posts_doc['content'].replace(videoId, '-----------')
+        request = self.posts.update(blogId=blogId, postId=postId, body=posts_doc, revert=True)
+        request.execute()
+
+
     def insert_amara_tags(self, blogId, postId, language_code):
         result_dict = self.extract_content_and_video(blogId, postId)
         content, videoId, posts_doc = result_dict['content'],result_dict['videoId'],result_dict['posts_doc']
@@ -70,16 +78,15 @@ class BlogClient:
         newContent = content[0:pos_iframe]+snippet_amara +content[pos_iframe:len(content)]
         posts_doc['content'] = newContent
         posts_doc['labels'].append('subtitled')
-        posts_doc['updated'] = posts_doc['published'] = str(datetime.datetime.now().isoformat(timespec='microseconds'))
-        request = self.posts.update(blogId=blogId,postId=postId,body=posts_doc, last_updated=datetime.utcnow())
+        posts_doc['updated'] = posts_doc['published'] = str(datetime.now().astimezone().isoformat(timespec='microseconds'))
+        request = self.posts.update(blogId=blogId,postId=postId,body=posts_doc)
         request.execute()
 
-
-    def update_video_in_blog_post(self, blogId, postId, old_youtube_ref,new_youtube_ref, posts):
+    def update_video_in_blog_post(self, blogId, postId, old_youtube_ref, new_youtube_ref, posts):
         request = posts.get(blogId=blogId, postId=postId)
         posts_doc = request.execute()
         posts_doc['content'] = posts_doc['content'].replace(old_youtube_ref, new_youtube_ref)
-        request = posts.update(blogId=blogId, postId=postId, body=posts_doc, last_updated=datetime.utcnow())
+        request = posts.update(blogId=blogId, postId=postId, body=posts_doc)
         request.execute()
 
     def retrieve_lyrics(self, blogId, postId ):
@@ -101,15 +108,16 @@ class BlogClient:
 
     def iterate_blog_posts(self, blogId):
         for item in self.iterate_blog_items(blogId):
-            content = item['content']
-            m_you_tube = re.search('src=\\\".*?youtube\.com\/embed\/([\w\-]{11})[\"\?]', content)
-            m_amara_embed = re.search('amara-embed', content)
-            video_id = m_you_tube.group(1) if m_you_tube else None
-            yield BlogPost(postId=item['id'],
-                           url=item['url'],
-                           title=item['title'].strip(),
-                           videoId=video_id,
-                           content=self.stripHtmlTags(item['content']),
-                           labels=item.get('labels', None),
-                           amara_embed=1 if m_amara_embed else 0,
-                           last_updated=datetime.utcnow())
+            if "published" in item:
+                content = item['content']
+                m_you_tube = re.search('src=\\\".*?youtube\.com\/embed\/([\w\-]{11})[\"\?]', content)
+                m_amara_embed = re.search('amara-embed', content)
+                video_id = m_you_tube.group(1) if m_you_tube else None
+                yield BlogPost(postId=item['id'],
+                               url=item['url'],
+                               title=item['title'].strip(),
+                               videoId=video_id,
+                               content=self.stripHtmlTags(item['content']),
+                               labels=item.get('labels', None),
+                               amara_embed=1 if m_amara_embed else 0,
+                               last_updated=datetime.utcnow())
